#
# spec file for package catatonit
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           catatonit
Version:        0.1.5
Release:        lp152.4.3.1
Summary:        A signal-forwarding process manager for containers
License:        GPL-3.0-or-later
Group:          System/Management
URL:            https://github.com/openSUSE/catatonit
Source0:        https://github.com/openSUSE/catatonit/releases/download/v%{version}/%{name}.tar.xz#/%{name}-%{version}.tar.xz
Source1:        https://github.com/openSUSE/catatonit/releases/download/v%{version}/%{name}.tar.xz.asc#/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
Source3:        %{name}-rpmlintrc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  file
BuildRequires:  gcc
BuildRequires:  glibc-devel-static
BuildRequires:  libtool

%description
Catatonit is a /sbin/init program for use within containers. It
forwards (almost) all signals to the spawned child, tears down
the container when the spawned child exits, and otherwise
cleans up other exited processes (zombies).

This is a reimplementation of other container init programs (such as
"tini" or "dumb-init"), but uses modern Linux facilities (such as
signalfd(2)) and has no additional features.

%prep
%setup -q

%build
autoreconf -fi
%configure
make %{?_smp_mflags}

# Make sure we *always* build a static binary. Otherwise we'll break containers
# that don't have the necessary shared libs.
file ./%{name} | grep 'statically linked'

%install
%make_install
ln -s %{_bindir}/%{name} %{buildroot}%{_bindir}/docker-init

%files
%defattr(-,root,root)
%doc README.md
%if 0%{?suse_version} >= 1500
%license COPYING
%else
%doc COPYING
%endif
%{_bindir}/%{name}
%{_bindir}/docker-init

%changelog
* Mon Mar  2 2020 Aleksa Sarai <asarai@suse.com>
- Update to catatonit v0.1.5, which fixes two bugs where catatonit would hang
  endlessly when pid1 died in very specific ways. bsc#1176155
* Tue Jan 29 2019 Aleksa Sarai <asarai@suse.com>
- Update to catatonit v0.1.4, which includes support for "-g".
* Wed Apr 18 2018 asarai@suse.com
- Update to catatonit v0.1.3, which includes a fix for docker compatiblity so
  that dockerd doesn't give spurrious warnings.
* Fri Apr  6 2018 asarai@suse.com
- Fix build to correctly build a static binary (which will allow it to work in
  all containers). This was caused by forgetting to include
  'glibc-devel-static'. I've added a check to ensure it doesn't happen by
  accident again.
- Add catatonit-rpmlintrc to include filters for "static binary" warnings,
  since this is intentional.
* Tue Apr  3 2018 jengelh@inai.de
- Update package descriptions.
* Thu Mar 29 2018 asarai@suse.com
- Update to catatonit v0.1.2 and update links to point to openSUSE repo.
* Tue Mar 27 2018 asarai@suse.com
- Update to catatonit v0.1.1, which includes a fix for the libtool requirement.
  This lets us build on much older distributions.
* Tue Mar 27 2018 asarai@suse.com
- Initial import of catatonit v0.1.0.
